# Exploratory Data Analysis

!!! tip inline end "Workbench EDA"
    The Workbench toolkit a set of plots that show EDA results, it also has a flexible plugin architecture to expand, enhance, or even replace the current set of web components [Dashboard](../aws_setup/dashboard_stack.md).
 
The Workbench framework has a broad range of Exploratory Data Analysis (EDA) functionality. Each time a DataSource or FeatureSet is created that data is run through a full set of EDA techniques:

- TBD
- TBD2

<figure style="float: right; width: 400px;">
<img alt="workbench_new_light" src="https://github.com/SuperCowPowers/workbench/assets/4806709/5f8b32a2-ed72-45f2-bd96-91b7bbbccff4">
<figcaption>Workbench Exploratory Data Analysis</figcaption>
</figure>

## Additional Resources

<img align="right" src="../../images/scp.png" width="180">

- Consulting Available: [SuperCowPowers LLC](https://www.supercowpowers.com)
